TexEngFormatter
===============

.. currentmodule:: stonerplots

.. autoclass:: TexEngFormatter
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TexEngFormatter.prefix

   .. rubric:: Methods Summary

   .. autosummary::

      ~TexEngFormatter.__call__
      ~TexEngFormatter.format_data
      ~TexEngFormatter.format_data_short

   .. rubric:: Attributes Documentation

   .. autoattribute:: prefix

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: format_data
   .. automethod:: format_data_short
